@@ -37,6 +37,11 @@ class ModuleCheckerSpider(scrapy.Spider):
                     "settings.json",
                     "setup.py"
             ):
+                if entity_ == "README.md":
+                    self.cache[entity_] = response.urljoin(
+                        entity.xpath(".//span/a/@href").get()
+                    )
+
                 continue
 
             yield scrapy.Request(
