@@ -291,26 +291,49 @@ class Setup:
         self.pipe = pipe
         self.logger = logger
         self.logger.info("Started Setup")
+        self.cache = {}
+
+    def close(self, *args):
+        return KillableProcess().kill() if twisted.internet.reactor.running else None
 
 
 class READMESetup(Setup):
-    def __init__(self, pipe, logger, url):
+    def __init__(self, pipe, logger, url, cache=None):
         super().__init__(pipe, logger)
 
-        crawler = KillableProcess()
+        self.pipe_cache = {} if cache is None else cache
 
-        crawler.crawl(
-            ReadmeSpider, pipe=self.pipe, url=url
+        crawler = scrapy.crawler.CrawlerProcess()
+
+        signal = crawler.crawl(
+            ReadmeSpider, pipe=self.cache, url=url
+        )
+
+        signal.addCallback(
+            self.close, bool(cache)
         )
 
         None if twisted.internet.reactor.running else crawler.start(True)
-        crawler.kill() if twisted.internet.reactor.running else None
+
+    def close(self, mode, *args):
+        super().close()
+
+        if mode:
+            self.pipe_cache = {
+                "result": self.cache,
+                "failed": not self.cache
+            }
+        else:
+            self.pipe_cache["readme"] = self.cache
+
+        self.pipe.put(
+            self.pipe_cache
+        )
 
 
 class ModuleCheckerSetup(Setup):
     def __init__(self, pipe, logger, url):
         super().__init__(pipe, logger)
-        self.cache = {}
 
         crawler = scrapy.crawler.CrawlerProcess()
 
@@ -321,24 +344,22 @@ class ModuleCheckerSetup(Setup):
         crawler.start(False)
 
     def start_another(self, *args):
-        if not ("settings.json" in self.cache and "setup.py" in self.cache):
-            return self.stop()
+        if "settings.json" not in self.cache or "setup.py" not in self.cache:
+            return self.close(True)
 
-        READMESetup(self.cache, self.logger, self.cache["README.md"])
+        self.cache["readme"] = False
+
+        if "README.md" not in self.cache:
+            return self.close(False)
+
+        READMESetup(self.pipe, self.logger, self.cache["README.md"], self.cache)
+
+    def close(self, failed=True):
+        super().close()
 
         self.pipe.put(
             {
-                "failed": False,
-                "results": self.cache
-            }
-        )
-
-    def stop(self):
-        KillableProcess().kill()
-
-        self.pipe.put(
-            {
-                "failed": True,
+                "failed": failed,
                 "result": self.cache
             }
         )
